@@ -122,3 +122,14 @@ test_that("wb_remove_comment", {
   expect_equal(wb$comments, wb2$comments)
 
 })
+
+test_that("print comment", {
+
+  c2 <- create_comment(text = "this is another comment",
+                       author = "Marco Polo")
+
+  exp <- "Author: Marco Polo\nText:\n Marco Polo:\nthis is another comment\n\nStyle:\n\n\n\n\nFont name: Calibri\nFont size: 11\nFont colour: #000000\n\n"
+  got <- capture_output(print(c2), print = TRUE)
+  expect_equal(exp, got)
+
+})
