@@ -415,6 +415,26 @@ test_that("set and remove row heights work", {
     "There are no initialized rows on this sheet"
   )
 
+  wb <- wb_workbook()$
+    add_worksheet()$
+    add_data(x = mtcars)$
+    set_row_heights(rows = 5:15, hidden = TRUE)
+
+  exp <- structure(
+    c(22L, `1` = 11L),
+    dim = 2L,
+    dimnames = structure(
+      list(
+        c("", "1")
+      ),
+      names = ""
+    ),
+    class = "table"
+  )
+  got <- table(wb$worksheets[[1]]$sheet_data$row_attr$hidden)
+
+  expect_equal(exp, got)
+
 })
 
 test_that("add_drawing works", {
@@ -461,6 +481,9 @@ test_that("add_drawing works", {
     add_data(x = data.frame(name = rownames(mtcars)), dims = "A2")
 
   # create wb_data object this will tell this mschart from this PR to create a file corresponding to openxlsx2
+  dat <- wb_data(wb, 1)
+  expect_equal(c(32L, 12L), dim(dat))
+
   dat <- wb_data(wb, 1, dims = "A2:G6")
 
   exp <- structure(
@@ -534,4 +557,90 @@ test_that("add_drawing works", {
   got <- wb$drawings_rels
   expect_equal(exp, got)
 
+
+  # write data starting at B2
+  wb <- wb_workbook()$
+    add_worksheet()$add_data(x = mtcars)$
+    add_worksheet()$add_data(x = mtcars)$
+    add_worksheet()$add_data(x = mtcars)$
+    add_worksheet()$add_data(x = mtcars)$
+    add_mschart(dims = "F4:L20", 2, graph = chart_01)$
+    add_mschart(dims = "F4:L20", 3, graph = chart_01)
+
+  exp <- list(
+    character(0),
+    "<Relationship Id=\"rId1\" Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing\" Target=\"../drawings/drawing2.xml\"/>",
+    "<Relationship Id=\"rId1\" Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing\" Target=\"../drawings/drawing3.xml\"/>",
+    character(0)
+  )
+  got <- wb$worksheets_rels
+  expect_equal(exp, got)
+
+  ## write different anchors
+  wb <- wb_workbook()$
+    add_worksheet()$add_data(x = mtcars)
+
+  scatter_plot <- ms_scatterchart(
+    data = wb_data(wb),
+    x = "mpg",
+    y = c("disp", "hp")
+  )
+
+  wb$
+    add_mschart(graph = scatter_plot)$
+    add_mschart(dims = "A1", graph = scatter_plot)$
+    add_mschart(dims = "F4:L20", graph = scatter_plot)
+
+  expect_true(grepl("absoluteAnchor", wb$drawings))
+  expect_true(grepl("oneCellAnchor", wb$drawings))
+  expect_true(grepl("twoCellAnchor", wb$drawings))
+
+})
+
+test_that("add_chartsheet works", {
+
+  skip_if_not_installed("mschart")
+
+  require(mschart)
+
+  wb <- wb_workbook()$
+    add_worksheet("A & B")$
+    add_data(x = mtcars)$
+    add_chartsheet(tabColour = "red")
+
+  dat <- wb_data(wb, 1, dims = "A1:E6")
+
+  # call ms_scatterplot
+  data_plot <- ms_scatterchart(
+    data = dat,
+    x = "mpg",
+    y = c("disp", "hp"),
+    labels = c("disp", "hp")
+  )
+
+  wb$add_mschart(graph = data_plot)
+
+  expect_equal(1, nrow(wb$charts))
+
+  expect_true(grepl("A &amp; B", wb$charts$chart))
+
+  expect_true(wb$is_chartsheet[[2]])
+
+  # add new worksheet and replace chart on chartsheet
+  wb$add_worksheet()$add_data(x = mtcars)
+  dat <- wb_data(wb, dims = "A1:E1;A7:E15")
+  data_plot <- ms_scatterchart(
+    data = dat,
+    x = "mpg",
+    y = c("disp", "hp"),
+    labels = c("disp", "hp")
+  )
+  wb$add_mschart(sheet = 2, graph = data_plot)
+
+  expect_equal(2L, nrow(wb$charts))
+
+  exp <- "xdr:absoluteAnchor"
+  got <- xml_node_name(wb$drawings, "xdr:wsDr")
+  expect_equal(exp, got)
+
 })
